@@ -26,6 +26,13 @@ parser.add_option("-L", "--list", dest="list",
 parser.add_option("-D", "--delete", dest="delete",
                   help="Delete event with specified ID",
                   metavar="'ID'")
+#toggle functions
+parser.add_option("-e", "--enable", dest="enable",
+                  help="Enable event with specified ID",
+                  metavar="'ID'")
+parser.add_option("-d", "--disable", dest="disable",
+                  help="Disable event with specified ID",
+                  metavar="'ID'")
 #edit option
 parser.add_option("-R", "--replace", dest="replace",
                   help="Replace newly created event with specified ID, optional",
@@ -102,10 +109,40 @@ if o.list:
                     else:
                         print "\t" + info + ": " + str(i[info])
     exit(0)
+#check if GUI is running
+try:
+    lock = open("/tmp/alarmed.lock", "r")
+    lock.close()
+    lock = True
+except:
+    lock = False
+if lock:
+    print """It seems like Alarmed GUI is running. Close it first if you want to use the CLI interface or remove /tmp/alarmed.lock"""
+    exit(1)
 #if delete is chosen, delete and exit
 if o.delete:
     print alarmed_backend.deleteEvent(int(o.delete))
     exit(0)
+#if user is toggling, do that and exit
+if o.enable:
+    eventInfo = alarmed_backend.loadEventInfo(o.enable)
+    if eventInfo:
+        a = alarmed_backend.makeEvent(eventInfo, int(eventInfo["id"]))
+        if a:
+            print "Enabled event with ID " + str(o.enable)
+        else:
+            print "Error occured enabling event, please report a bug"
+    else:
+        print "Event with ID " + str(o.enable) + " does not exist"
+    exit(0)
+if o.disable:
+    eventInfo = alarmed_backend.loadEventInfo(o.disable)
+    if eventInfo:
+        alarmed_backend.deleteEventAlarmd(eventInfo)
+        print "Disabled event with ID " + str(o.disable)
+    else:
+        print "Event with ID " + str(o.disable) + " does not exist"
+    exit(0)
 #if list-presets is chosen, list them and exit
 if o.list_presets:
     presetList = alarmed_backend.loadPresetList()
