@@ -1,24 +1,15 @@
 #!/usr/bin/env python
 
 """GUI module for alarmed"""
+import os
 import sys
 import signal
 import time
 import datetime
 from PySide import QtCore, QtGui, QtMaemo5
+#~ from PyQt4 import QtCore, QtGui
 import alarmed_backend
 
-class EventWidget(QtGui.QWidget):
-    def __init__(self, title, content, parent=None):
-        """A single event with title and content for the list"""
-        QtGui.QWidget.__init__(self, parent)
-        self.title = QtGui.QLabel(title)
-        self.content = QtGui.QLabel(content)
-        self.allVBox = QtGui.QVBoxLayout()
-        self.allVBox.addWidget(self.title)
-        self.allVBox.addWidget(self.content)
-        self.setLayout(self.allVBox)
-
 class AlarmedGUI(QtGui.QWidget):
     def __init__(self, parent=None):
         """Main window displaying the list of events and 3 buttons"""
@@ -36,6 +27,8 @@ class AlarmedGUI(QtGui.QWidget):
         self.eventList = QtGui.QListWidget()
         self.eventList.setSelectionMode(
                      QtGui.QAbstractItemView.SingleSelection)
+        self.connect(self.eventList, QtCore.SIGNAL("itemClicked(QListWidgetItem*)"),
+                     self.toggleEvent)
         self.addRemoveHBox = QtGui.QHBoxLayout()
         self.addRemoveHBox.addWidget(self.newEventButton)
         self.addRemoveHBox.addWidget(self.deleteEventButton)
@@ -48,6 +41,7 @@ class AlarmedGUI(QtGui.QWidget):
         eventList = alarmed_backend.loadEventList()
         for eventInfo in eventList:
             self.addEventToList(eventInfo)
+        self.checkSum = self.checkSumEventList()
         #read the available fields from the backend
         self.fields = alarmed_backend.loadFieldsDict()
         self.weekdays = []
@@ -63,11 +57,17 @@ class AlarmedGUI(QtGui.QWidget):
             self.eventList.removeItemWidget(
                            self.eventList.currentItem())
         newEventTitle, newEventContent = alarmed_backend.generateEventString(eventInfo)
-        newEvent = QtGui.QListWidgetItem() #(newEventString)
-        newEventWidget = EventWidget(newEventTitle, newEventContent)
+        newEvent = QtGui.QListWidgetItem(newEventTitle + "\n" + newEventContent)
+        newEvent.setFlags(newEvent.flags() | QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsSelectable | QtCore.Qt.ItemIsEnabled)
+        try:
+            if eventInfo["enabled"] == 0:
+                newEvent.setCheckState(QtCore.Qt.Unchecked)
+            else:
+                newEvent.setCheckState(QtCore.Qt.Checked)
+        except:
+            newEvent.setCheckState(QtCore.Qt.Checked)
         newEvent.eventInfo = eventInfo
         self.eventList.addItem(newEvent)
-        self.eventList.setItemWidget(newEvent, newEventWidget)
 
     def removeEvent(self):
         """Calls backend to remove an event"""
@@ -86,6 +86,29 @@ class AlarmedGUI(QtGui.QWidget):
         else:
             self.showError('''<font color="#000000">Select an item first</font>''')
 
+    def checkSumEventList(self):
+        checkSum = 0
+        for i in range(self.eventList.count()):
+            checkSum = checkSum + int(self.eventList.item(i).checkState())
+        return checkSum
+
+    def toggleEvent(self):
+        """Enable or disable an existing event"""
+        tempCheckSum = self.checkSumEventList()
+        if self.checkSum != tempCheckSum:
+            self.checkSum = tempCheckSum
+            item = self.eventList.currentItem()
+            state = item.checkState()
+            id = int(item.eventInfo["id"])
+            if state == 0:
+                alarmed_backend.deleteEventAlarmd(item.eventInfo)
+            if state == 2:
+                a = alarmed_backend.makeEvent(item.eventInfo, int(item.eventInfo["id"]))
+                if a == "invalid":
+                    self.showError('''<font color="#000000">Please pick a date & time in the future</font>''')
+                    return False
+                
+
     def openEventDialog(self, item=None):
         """Present a dialog to set and edit events"""
         self.newEventDialog = QtGui.QDialog(self)
@@ -635,10 +658,15 @@ class AlarmedGUI(QtGui.QWidget):
             return False
         #add event to gui list
         self.addEventToList(eventInfo, self.editing)
-        
+        self.checkSum = self.checkSumEventList()
         self.newEventDialog.accept()
 
 app = QtGui.QApplication(sys.argv)
 widget = AlarmedGUI()
 widget.show()
-sys.exit(app.exec_())
+lock = open("/tmp/alarmed.lock", "w")
+lock.write("1")
+lock.close()
+r = app.exec_()
+os.remove("/tmp/alarmed.lock")
+sys.exit(r)
